# TODO
# - -rt subpackage? -lang subpackage?
# - <meta>-xxx keybindings (alt+something) incompatibility
#   https://github.com/neovim/neovim/issues/5576
#
# Conditional build:
%bcond_with	prefer_lua		# Prefer Lua over LuaJit

%ifarch x32
%define	with_prefer_lua 1
%endif

Summary:	Vim-fork focused on extensibility and agility
Name:		neovim
Version:	0.3.8
Release:	1
License:	Apache v2.0
Group:		Applications/Editors/Vim
# Source0Download: https://github.com/neovim/neovim/releases
Source0:	https://github.com/neovim/neovim/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	6b0eda6c3c6261c82f8a61f9c2d85fcd
URL:		https://neovim.io/
Source2:	%{name}.svg
Patch0:		desktop.patch
Patch1:		https://github.com/neovim/neovim/pull/12142.patch
# Patch1-md5:	40bf36c33b4c49270243b39b916e164c
BuildRequires:	cmake >= 2.8.7
BuildRequires:	gcc >= 6:4.4
BuildRequires:	gettext-devel
BuildRequires:	jemalloc-devel
BuildRequires:	libstdc++-devel
BuildRequires:	libtermkey-devel
BuildRequires:	libuv-devel
BuildRequires:	libvterm-devel < 0.1.3
BuildRequires:	lua-bitop >= 1.0.2
BuildRequires:	lua-lpeg
BuildRequires:	lua-mpack >= 1.0.2
BuildRequires:	msgpack-devel >= 1.1.0
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.596
BuildRequires:	unibilium-devel
%if %{with prefer_lua}
BuildRequires:	lua51
BuildRequires:	lua51-devel
%else
BuildRequires:	luajit-devel
%endif
Requires:	desktop-file-utils
Requires:	gtk-update-icon-cache
Requires:	hicolor-icon-theme
Suggests:	python-neovim
Suggests:	python3-neovim
Suggests:	ruby-neovim
Suggests:	xsel
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# gcc 4.0 and better turn on _FORTIFY_SOURCE=2 automatically. This currently
# does not work with Neovim due to some uses of dynamically-sized structures.
# See https://github.com/neovim/neovim/issues/223 for details.
%define		filterout_c	-Wp,-D_FORTIFY_SOURCE=2

%description
Neovim is a refactor - and sometimes redactor - in the tradition of
Vim, which itself derives from Stevie. It is not a rewrite, but a
continuation and extension of Vim. Many rewrites, clones, emulators
and imitators exist; some are very clever, but none are Vim. Neovim
strives to be a superset of Vim, notwithstanding some intentionally
removed misfeatures; excepting those few and carefully-considered
excisions, Neovim is Vim. It is built for users who want the good
parts of Vim, without compromise, and more.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
install -d .deps build
cd .deps
%cmake \
	-DUSE_BUNDLED=OFF \
	-DUSE_BUNDLED_JEMALLOC=OFF \
	-DUSE_BUNDLED_UNIBILIUM=OFF \
	-DUSE_BUNDLED_LIBTERMKEY=OFF \
	-DUSE_BUNDLED_LIBVTERM=OFF \
	-DUSE_BUNDLED_LIBUV=OFF \
	-DUSE_BUNDLED_MSGPACK=OFF \
	-DUSE_BUNDLED_LUAJIT=OFF \
	-DUSE_BUNDLED_LUAROCKS=OFF \
	-DUSE_BUNDLED_LUV=OFF \
	../third-party
%{__make}

cd ../build
%cmake \
	-DPREFER_LUA=%{!?with_prefer_lua:OFF}%{?with_prefer_lua:ON} \
	-DLUA_PRG=/usr/bin/lua5.1 \
	-DENABLE_JEMALLOC=ON \
	-DLUAJIT_USE_BUNDLED=OFF \
	-DLIBUV_USE_BUNDLED=OFF \
	-DMSGPACK_USE_BUNDLED=OFF \
	-DUNIBILIUM_USE_BUNDLED=OFF \
	-DLIBTERMKEY_USE_BUNDLED=OFF \
	-DLIBVTERM_USE_BUNDLED=OFF \
	-DJEMALLOC_USE_BUNDLED=OFF \
	..

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT{/etc/xdg/nvim,%{_iconsdir}/hicolor/scalable/apps}
touch $RPM_BUILD_ROOT/etc/xdg/nvim/init.vim
cp -p %{SOURCE2} $RPM_BUILD_ROOT%{_iconsdir}/hicolor/scalable/apps/nvim.svg

%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/cs.cp1250
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/ja.euc-jp
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/ko.UTF-8
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/no
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/pl.UTF-8
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/sk.cp1250
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/zh_CN.UTF-8
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/zh_TW.UTF-8

%find_lang nvim

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_desktop_database
%update_icon_cache hicolor
%banner -e -o %{name} << 'EOF'

The Neovim executable is called 'nvim'. To use your existing Vim
configuration:
    ln -s ~/.vim ~/.config/nvim
    ln -s ~/.vimrc ~/.config/nvim/init.vim
See ':help nvim' for more information on Neovim.

If you want support for Python plugins such as YouCompleteMe, you need
to install a Python module in addition to Neovim itself.

See ':help provider-python' or this page for more information:
    http://neovim.io/doc/user/provider.html

If you have any questions, have a look at:
    https://github.com/neovim/neovim/wiki/FAQ.
EOF

%postun
%update_desktop_database
%update_icon_cache hicolor

%files -f nvim.lang
%defattr(644,root,root,755)
%doc BACKERS.md CONTRIBUTING.md LICENSE README.md
%dir /etc/xdg/nvim
%config(noreplace) %verify(not md5 mtime size) /etc/xdg/nvim/init.vim
%attr(755,root,root) %{_bindir}/nvim
%{_mandir}/man1/nvim.1*
%{_datadir}/nvim
%{_desktopdir}/nvim.desktop
%{_pixmapsdir}/nvim.png
%{_iconsdir}/hicolor/*/apps/nvim.svg
%changelog
* Sun Nov 08 2020 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/neovim.git;a=log;h=master

* Fri Nov 06 2020 Elan Ruusamäe <glen@pld-linux.org> 1b20afa
- Rename bcond to prefer_lua, fix for x32

* Fri Nov 06 2020 Elan Ruusamäe <glen@pld-linux.org> 58461eb
- Requires older libvterm-devel

* Fri Nov 06 2020 Elan Ruusamäe <glen@pld-linux.org> 1a0c55f
- Lua deps are available for lua 5.1 only

* Fri Nov 06 2020 Elan Ruusamäe <glen@pld-linux.org> 1ffaa60
- Lua can't be disabled, just lua flavor be changed

* Fri Nov 06 2020 Elan Ruusamäe <glen@pld-linux.org> def4dbb
- build fixes for gcc-10

* Fri Nov 06 2020 Elan Ruusamäe <glen@pld-linux.org> 8179654
- Apply desktop.patch

* Fri Nov 06 2020 Elan Ruusamäe <glen@pld-linux.org> 8d564b1
- Up to 0.3.8

* Mon May 18 2020 Jan Rękorajski <baggins@pld-linux.org> f700a5e
- disable LUA (error: lua-mpack: no such package)

* Mon May 06 2019 Elan Ruusamäe <glen@pld-linux.org> f5069d1
- up to 0.3.5

* Mon Jan 07 2019 Elan Ruusamäe <glen@pld-linux.org> 2e3431e
- up to 0.3.3

* Sun Dec 23 2018 Elan Ruusamäe <glen@pld-linux.org> 6b16d9c
- up to 0.3.1; use upstream desktop file

* Tue Jan 16 2018 Elan Ruusamäe <glen@pld-linux.org> 69dc98a
- up to 0.2.2

* Thu Aug 10 2017 Elan Ruusamäe <glen@pld-linux.org> f7b621b
- up to 0.2.0

* Fri Jan 20 2017 Elan Ruusamäe <glen@delfi.ee> cebcf7f
- add link for vim/nvim bindings incompat

* Fri Jan 20 2017 Elan Ruusamäe <glen@delfi.ee> f4df6d0
- up to 0.1.7

* Fri Jan 20 2017 Elan Ruusamäe <glen@delfi.ee> 4350fc3
- up to 0.1.6

* Tue Oct 11 2016 Elan Ruusamäe <glen@delfi.ee> 82b424f
- rebuild for x32
- release 2 (by relup.sh)

* Mon Sep 26 2016 Elan Ruusamäe <glen@delfi.ee> 9277ef3
- annoyed by alt+<x> hotkeys not working

* Sun Sep 18 2016 Elan Ruusamäe <glen@delfi.ee> 3f05c04
- suggest ruby-neovim

* Sun Sep 18 2016 Elan Ruusamäe <glen@delfi.ee> 3fb7b0d
- package nvimi/init.vim - place for per site global customizations

